@@ -4,7 +4,7 @@ except ImportError:
     __version__ = "unknown"
 
 # replace the asterisk with named imports
-from .lazy_openslide import napari_get_reader
+from .lazy_openslide import napari_get_reader, OpenSlideStore
 
 
 __all__ = ["napari_get_reader"]
